Changelog
=========

:Version: 1.0 of 2017-09-24

Version bump after testing upload to GitHub and PyPI, as well as pip installation
and output correctness under Python 2.7 and 3.6.

:Version: 1.0-rc.1 of 2017-09-23

Refactoring: moved powerlaw_psd_gaussian into the present pure python module to 
release it to the public in pip-installable form.


:Version: [unreleased] of 2014-04-07

powerlaw_psd_gaussian was part of a personal collection of random number
generation algorithms for research written in python and c.
